@@ -191,7 +191,7 @@ import sys
 from mako.lookup import TemplateLookup
 from mako.exceptions import TopLevelLookupException
 
-__version__ = '0.2.0'
+__version__ = '0.2.1'
 """
 The current version of pdoc. This value is read from `setup.py`.
 """
@@ -325,11 +325,21 @@ def import_module(module_name):
 def _source(obj):
     """
     Returns the source code of the Python object `obj` as a list of
-    lines. If the source code doesn't exist, then the empty list is
-    returned.
+    lines. If the source code doesn't exist, try to get the source code
+    of `obj.__wrapped__`. In Python 3.2 and above, this is automatically added to decorated
+    functions as a reference to the original function. In previous versions of Python, this
+    behavior can be accomplished by use of the
+    [decorator module](http://pypi.python.org/pypi/decorator/3.4.0).
+
+    If neither of
+    these have source code, then the empty list is returned.
     """
     try:
         return inspect.getsourcelines(obj)[0]
+    except:
+        pass
+    try:
+        return inspect.getsourcelines(obj.__wrapped__)[0]
     except:
         return []
 
@@ -466,9 +476,15 @@ class Doc (object):
     @property
     def source(self):
         """
-        Returns the source code for the underlying Python object as a
-        list of lines. If the source code can't be retrieved, then the
-        empty list is returned.
+        Returns the source code of the Python object `obj` as a list of
+        lines. If the source code doesn't exist, try to get the source code
+        of `obj.__wrapped__`. In Python 3.2 and above, this is automatically added to decorated
+        functions as a reference to the original function. In previous versions of Python, this
+        behavior can be accomplished by use of the
+        [decorator module](http://pypi.python.org/pypi/decorator/3.4.0).
+
+        If neither of
+        these have source code, then the empty list is returned.
         """
         assert False, 'subclass responsibility'
 
